{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "abundance profile",
            "doc": "create abundance profile from expanded annotated sims files\nmd5:    sims_abundance.py -t md5 -i <input> -o <output> --coverage <coverage> --cluster <cluster> --md5index <md5index>\nlca:    sims_abundance.py -t lca -i <input> -o <output> --coverage <coverage> --cluster <cluster>\nsource: sims_abundance.py -t source -i <input> -o <output> --coverage <coverage> --cluster <cluster>\n",
            "hints": [
                {
                    "dockerPull": "mgrast/pipeline:4.03",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "sims_abundance.log",
            "stderr": "sims_abundance.error",
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "prefix": "--cluster"
                            }
                        }
                    ],
                    "doc": "Optional input file(s), cluster mapping",
                    "id": "#sims_abundance.tool.cwl/cluster"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Optional input file, assembly coverage",
                    "inputBinding": {
                        "prefix": "--coverage"
                    },
                    "id": "#sims_abundance.tool.cwl/coverage"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-i"
                        }
                    },
                    "doc": "Input expanded sims file",
                    "id": "#sims_abundance.tool.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Optional input file, md5,seek,length",
                    "inputBinding": {
                        "prefix": "--md5_index"
                    },
                    "id": "#sims_abundance.tool.cwl/md5index"
                },
                {
                    "type": "string",
                    "doc": "Output abundance profile",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#sims_abundance.tool.cwl/outName"
                },
                {
                    "type": "string",
                    "doc": "Profile type",
                    "format": [
                        "#sims_abundance.tool.cwl/profileType/ProfileTypes.cv.yamlmd5",
                        "#sims_abundance.tool.cwl/profileType/ProfileTypes.cv.yamllca",
                        "#sims_abundance.tool.cwl/profileType/ProfileTypes.cv.yamlsource"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#sims_abundance.tool.cwl/profileType"
                }
            ],
            "baseCommand": [
                "sims_abundance.py"
            ],
            "id": "#sims_abundance.tool.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#sims_abundance.tool.cwl/error",
                    "outputBinding": {
                        "glob": "sims_abundance.error"
                    }
                },
                {
                    "type": "File",
                    "id": "#sims_abundance.tool.cwl/info",
                    "outputBinding": {
                        "glob": "sims_abundance.log"
                    }
                },
                {
                    "type": "File",
                    "doc": "Output abundance profile file",
                    "outputBinding": {
                        "glob": "$(inputs.outName)"
                    },
                    "id": "#sims_abundance.tool.cwl/output"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "abundance",
            "doc": "abundace profiles from annotated files, for protein and/or rna",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/clustMaps"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/coverage"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/expandSims"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/filterSims"
                },
                {
                    "type": "string",
                    "id": "#main/jobid"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/lcaAnns"
                },
                {
                    "type": "File",
                    "id": "#main/md5index"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/lcaProfile/output",
                    "id": "#main/lcaProfileOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/md5Profile/output",
                    "id": "#main/md5ProfileOut"
                },
                {
                    "type": "File",
                    "outputSource": "#main/sourceStats/output",
                    "id": "#main/sourceStatsOut"
                }
            ],
            "steps": [
                {
                    "run": "#sims_abundance.tool.cwl",
                    "in": [
                        {
                            "source": "#main/clustMaps",
                            "id": "#main/lcaProfile/cluster"
                        },
                        {
                            "source": "#main/coverage",
                            "id": "#main/lcaProfile/coverage"
                        },
                        {
                            "source": "#main/lcaAnns",
                            "id": "#main/lcaProfile/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).700.annotation.lca.abundance",
                            "id": "#main/lcaProfile/outName"
                        },
                        {
                            "valueFrom": "lca",
                            "id": "#main/lcaProfile/profileType"
                        }
                    ],
                    "out": [
                        "#main/lcaProfile/output"
                    ],
                    "id": "#main/lcaProfile"
                },
                {
                    "run": "#sims_abundance.tool.cwl",
                    "in": [
                        {
                            "source": "#main/clustMaps",
                            "id": "#main/md5Profile/cluster"
                        },
                        {
                            "source": "#main/coverage",
                            "id": "#main/md5Profile/coverage"
                        },
                        {
                            "source": "#main/filterSims",
                            "id": "#main/md5Profile/input"
                        },
                        {
                            "source": "#main/md5index",
                            "id": "#main/md5Profile/md5index"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).700.annotation.md5.abundance",
                            "id": "#main/md5Profile/outName"
                        },
                        {
                            "valueFrom": "md5",
                            "id": "#main/md5Profile/profileType"
                        }
                    ],
                    "out": [
                        "#main/md5Profile/output"
                    ],
                    "id": "#main/md5Profile"
                },
                {
                    "run": "#sims_abundance.tool.cwl",
                    "in": [
                        {
                            "source": "#main/clustMaps",
                            "id": "#main/sourceStats/cluster"
                        },
                        {
                            "source": "#main/coverage",
                            "id": "#main/sourceStats/coverage"
                        },
                        {
                            "source": "#main/expandSims",
                            "id": "#main/sourceStats/input"
                        },
                        {
                            "source": "#main/jobid",
                            "valueFrom": "$(self).700.annotation.source.stats",
                            "id": "#main/sourceStats/outName"
                        },
                        {
                            "valueFrom": "source",
                            "id": "#main/sourceStats/profileType"
                        }
                    ],
                    "out": [
                        "#main/sourceStats/output"
                    ],
                    "id": "#main/sourceStats"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
